@@ -169,7 +169,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.25'
+__version__ = '0.1.26'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -997,9 +997,10 @@ class LiszDataMixin(ABC):
             flow_path.append(self.flow_path[-1])
 
         self.change_app_state('flow_path', flow_path)
-        # noinspection PyAttributeOutsideInit
-        event_kwargs['flow_id'] = self._last_focus_flow_id = id_of_flow('')     # reset _last_focus_flow_id of last node
         self.play_sound(id_of_flow('enter', 'item'))
+
+        event_kwargs['flow_id'] = id_of_flow('')
+        event_kwargs['reset_last_focus_flow_id'] = True             # reset _last_focus_flow_id of last node
         event_kwargs['changed_event_name'] = 'refresh_all'
 
         return True
